#ifndef SCRIPT_HPP_INCLUDED
#define SCRIPT_HPP_INCLUDED

#include <string>
#include <vector>
#include <atomic>
#include "Types/Timer.hpp"

extern std::atomic_bool Terminate;

extern void Setup();
extern bool OnStart();
extern bool Loop();
extern void OnEnd();

typedef struct
{
    std::string Name = "";
    std::string Description = "";
    std::string Version = "";
    std::string Category = "";
    std::string Author = "";
    std::string UID = "";
    std::string ForumPage = "";
} ScriptInfo;

typedef struct
{
    std::string Username;
    std::string Password;
    bool Member;
    bool HasPin;
    std::string BankPin;
    std::string World;
    bool UseProxy;
    std::string ProxyHost;
    std::string ProxyPort;
    std::string ProxyUsername;
    std::string ProxyPassword;
    std::int32_t InteractableMean;
    float InteractableDeviation;
    std::int32_t MoveMean;
    float MoveDeviation;
    std::int32_t MouseDownMean;
    float MouseDownDeviation;
    std::int32_t MouseUpMean;
    float MouseUpDeviation;
    std::int32_t KeyDownMean;
    float KeyDownDeviation;
    std::int32_t KeyUpMean;
    float KeyUpDeviation;
    std::int32_t ScrollAmount;
    float ScrollAmountDeviation;
    std::int32_t ScrollGapMean;
    float ScrollGapDeviation;
    std::int32_t ScrollDelayMean;
    float ScrollDelayDeviation;
    float StandardDeviationX;
    float StandardDeviationY;
    float BoxProbabilityX;
    float BoxProbabilityY;
    float ConvexProbabilityX;
    float ConvexProbabilityY;
    float ItemProbabilityX;
    float ItemProbabilityY;
    float MenuProbabilityX;
    float MenuProbabilityY;
    float WidgetProbabilityX;
    float WidgetProbabilityY;
    float PointGenAccuracy;
    float FatigueGain;
    float FatigueLoss;
    float FatigueMax;
    bool MiniBreakEnabled;
    float MiniBreakEvery;
    float MiniBreakEveryDeviation;
    float MiniBreakFor;
    float MiniBreakForDeviation;
    bool ShortBreakEnabled;
    float ShortBreakEvery;
    float ShortBreakEveryDeviation;
    float ShortBreakFor;
    float ShortBreakForDeviation;
    bool LongBreakEnabled;
    float LongBreakEvery;
    float LongBreakEveryDeviation;
    float LongBreakFor;
    float LongBreakForDeviation;
} PlayerProfile;

void TerminateScript();
Timer GetScriptTimer();
void SetScriptInfo(ScriptInfo);
void GetScriptInfo(ScriptInfo&);
void SetPlayerProfile(PlayerProfile);
void RequestArgument(std::string Argument, std::string Description);
std::vector<std::string> GetArguments();
std::vector<std::string> GetArgumentDescriptions();
void SetArgument(std::string Argument, std::string Value);
std::string GetArgument(std::string Argument);
std::uint32_t GetLoopDelay();
void SetLoopDelay(std::uint32_t Delay);

#endif // SCRIPT_HPP_INCLUDED
